@@ -1,3 +1,5 @@
+from __future__ import print_function
+
 import warnings
 warnings.filterwarnings("ignore", "apt API not stable yet", FutureWarning)
 import apt
@@ -30,7 +32,7 @@ class LanguageInformation(object):
         # langPack/support status 
         self.languagePkgList = {}
         self.languagePkgList["languagePack"] = LanguagePackageStatus(languageCode, "language-pack-%s")
-        for langpkg_status in self.languagePkgList.itervalues():
+        for langpkg_status in self.languagePkgList.values():
             pkgname = langpkg_status.pkgname_template % languageCode
             langpkg_status.available = pkgname in cache
             if langpkg_status.available:
@@ -109,18 +111,14 @@ class LanguageSelectorPkgCache(apt.Cache):
     def tryChangeDetails(self, li):
         " commit changed status of list items"""
         # we iterate over items of type LanguagePackageStatus
-        for (key, item) in li.languagePkgList.iteritems():
+        for (key, item) in li.languagePkgList.items():
             if item.doChange:
                 pkgs = self.lang_support.by_locale(li.languageCode, installed=item.installed)
-                #print "XXX pkg list for lang %s, installed: %s" % (item.languageCode, str(item.installed))
+                #print("XXX pkg list for lang %s, installed: %s" % (item.languageCode, str(item.installed)))
                 try:
                     if item.installed:
-                        # We are selective when deleting language support packages to
-                        # prevent removal of packages that are not language specific.
                         for pkgname in pkgs:
-                            if pkgname.startswith('language-pack-') or \
-                               pkgname.endswith('-' + li.languageCode):
-                                self[pkgname].mark_delete()
+                            self[pkgname].mark_delete()
                     else:
                         for pkgname in pkgs:
                             self[pkgname].mark_install()
@@ -134,7 +132,7 @@ class LanguageSelectorPkgCache(apt.Cache):
             if code == 'zh':
                 continue
             li = LanguageInformation(self, code, lang)
-            if [s for s in li.languagePkgList.itervalues() if s.available]:
+            if [s for s in li.languagePkgList.values() if s.available]:
                 res.append(li)
 
         return res
@@ -147,5 +145,5 @@ if __name__ == "__main__":
     li = LocaleInfo("languagelist", datadir)
 
     lc = LanguageSelectorPkgCache(li,apt.progress.OpProgress())
-    print "available language information"
-    print ", ".join(["%s" %x for x in lc.getLanguageInformation()])
+    print("available language information")
+    print(", ".join(["%s" %x for x in lc.getLanguageInformation()]))
