@@ -4,36 +4,33 @@
 # Released under the GPL
 #
 
+from __future__ import print_function
+
 import gettext
 import grp
 import locale
 import os
 import pwd
 import re
-import shutil
-import string
 import subprocess
 import sys
-import thread
 import time
-import tempfile
 from gettext import gettext as _
 
-from gi.repository import GObject, Gdk, Gtk, Pango
+from gi.repository import GObject, Gdk, Gtk #, Pango
 
 import apt
-import apt_pkg
 
 import aptdaemon.client
 from defer import inline_callbacks
 from aptdaemon.enums import *
 from aptdaemon.gtk3widgets import AptProgressDialog
 
-from LanguageSelector.LocaleInfo import LocaleInfo
 from LanguageSelector.LanguageSelector import *
 from LanguageSelector.ImSwitch import ImSwitch
 from LanguageSelector.macros import *
 from LanguageSelector.utils import language2locale
+from LanguageSelector.LangCache import ExceptionPkgCacheBroken
  
 (LIST_LANG,                     # language (i18n/human-readable)
  LIST_LANG_INFO                 # the short country code (e.g. de, pt_BR)
@@ -78,6 +75,7 @@ def insensitive(f):
         args[0].setSensitive(False)
         res = f(*args, **kwargs)
         args[0].setSensitive(True)
+        return res
     return wrapper
 
 
@@ -102,23 +100,27 @@ class GtkProgress(apt.progress.base.OpProgress):
         host_window.get_window().set_functions(Gdk.WMFunction.MOVE)
         self._window.set_transient_for(parent)
 
-    def update(self, percent):
-        #print percent
-        #print self.Op
-        #print self.SubOp
+    def update(self, percent=None):
+        #print(percent)
+        #print(self.Op)
+        #print(self.SubOp)
         self._window.show()
         self._parent.set_sensitive(False)
-        # if the old percent was higher, a new progress was started
-        if self.old > percent:
-            # set the borders to the next interval
-            self.base = self.next
-            try:
-                self.next = int(self.steps.pop(0))
-            except:
-                pass
-        progress = self.base + percent/100 * (self.next - self.base)
-        self.old = percent
-        self._progressbar.set_fraction(progress/100.0)
+        if percent is None:
+            self.old = 0
+            self._progressbar.pulse()
+        else:
+            # if the old percent was higher, a new progress was started
+            if self.old > percent:
+                # set the borders to the next interval
+                self.base = self.next
+                try:
+                    self.next = int(self.steps.pop(0))
+                except:
+                    pass
+            progress = self.base + percent/100 * (self.next - self.base)
+            self.old = percent
+            self._progressbar.set_fraction(progress/100.0)
         while Gtk.events_pending():
             Gtk.main_iteration()
     def done(self):
@@ -137,8 +139,16 @@ class GtkLanguageSelector(LanguageSelectorBase):
         self.widgets.add_from_file(datadir+"/data/LanguageSelector.ui")
         self.widgets.connect_signals(self)
 
-        self.is_admin = (os.getuid() == 0 or
-                         grp.getgrnam("admin")[2] in os.getgroups())
+        try:
+            in_grp_admin = grp.getgrnam("admin")[2] in os.getgroups()
+        except KeyError:
+            in_grp_admin = False
+        try:
+            in_grp_sudo = grp.getgrnam("sudo")[2] in os.getgroups()
+        except KeyError:
+            in_grp_sudo = False
+
+        self.is_admin = (os.getuid() == 0 or in_grp_sudo or in_grp_admin)
 
         # see if we have any other human users on this system
         self.has_other_users = False
@@ -245,7 +255,7 @@ class GtkLanguageSelector(LanguageSelectorBase):
 
         o = self.widgets.get_object(name)
         if o is None:
-            raise AttributeError, 'No such widget: ' + name
+            raise AttributeError('No such widget: ' + name)
         return o
 
     def run(self):
@@ -292,7 +302,7 @@ class GtkLanguageSelector(LanguageSelectorBase):
             # check for active and inconsitent 
             inconsistent = langInfo.inconsistent
             #if inconsistent:
-            #    print "%s is inconsistent" % langInfo.language
+            #    print("%s is inconsistent" % langInfo.language)
 
             cell.set_property("active", langInfo.fullInstalled)
             cell.set_property("inconsistent", inconsistent)
@@ -300,7 +310,6 @@ class GtkLanguageSelector(LanguageSelectorBase):
         def lang_view_func(cell_layout, renderer, model, iter, data):
             langInfo = model.get_value(iter, LIST_LANG_INFO)
             langName = model.get_value(iter, LIST_LANG)
-            inconsistent = langInfo.inconsistent
             if (langInfo.changes) :
                 markup = "<b>%s</b>" % langName
             else:
@@ -326,7 +335,6 @@ class GtkLanguageSelector(LanguageSelectorBase):
         """ do all the treeview setup here """
         def lang_view_func(cell_layout, renderer, model, iter, data):
             langInfo = model.get_value(iter, LANGTREEVIEW_CODE)
-            langName = model.get_value(iter, LANGTREEVIEW_LANGUAGE)
             greyFlag = False
             myiter = model.get_iter_first()
             while myiter:
@@ -366,8 +374,8 @@ class GtkLanguageSelector(LanguageSelectorBase):
     def debug_pkg_status(self):
         langInfo = self._get_langinfo_on_cursor()
         for pkg in langInfo.languagePkgList.items() :
-            print ("%s, available: %s, installed: %s, doChange: %s" % (pkg[0], pkg[1].available, pkg[1].installed, pkg[1].doChange))
-        print ("inconsistent? : %s" % langInfo.inconsistent)
+            print("%s, available: %s, installed: %s, doChange: %s" % (pkg[0], pkg[1].available, pkg[1].installed, pkg[1].doChange))
+        print("inconsistent? : %s" % langInfo.inconsistent)
 
     def check_status(self):
         changed = False
@@ -382,7 +390,7 @@ class GtkLanguageSelector(LanguageSelectorBase):
                             countRemove = countRemove + 1
                         else:
                             countInstall = countInstall + 1
-        #print "%(INSTALL)d to install, %(REMOVE)d to remove" % (countInstall, countRemove)
+        #print("%(INSTALL)d to install, %(REMOVE)d to remove" % (countInstall, countRemove))
         # Translators: %(INSTALL)d is parsed; either keep it exactly as is or remove it entirely, but don't translate "INSTALL".
         textInstall = gettext.ngettext("%(INSTALL)d to install", "%(INSTALL)d to install", countInstall) % {'INSTALL': countInstall}
         # Translators: %(REMOVE)d is parsed; either keep it exactly as is or remove it entirely, but don't translate "REMOVE".
@@ -405,7 +413,7 @@ class GtkLanguageSelector(LanguageSelectorBase):
 #    @honorBlockedSignals
 #    @insensitive
 #    def on_combobox_system_language_changed(self, widget):
-#        #print "on_combobox_system_language_changed()"
+#        #print("on_combobox_system_language_changed()")
 #        if self.writeSystemDefaultLang():
 #            # queue a restart of gdm (if it is runing) to make the new
 #            # locales usable
@@ -420,7 +428,7 @@ class GtkLanguageSelector(LanguageSelectorBase):
 #    @honorBlockedSignals
 #    @insensitive
 #    def on_combobox_user_language_changed(self, widget):
-#        #print "on_combobox_user_language_changed()"
+#        #print("on_combobox_user_language_changed()")
 #        self.check_input_methods()
 #        self.writeUserDefaultLang()
 #        self.updateUserDefaultCombo()
@@ -437,8 +445,8 @@ class GtkLanguageSelector(LanguageSelectorBase):
             return
         # get the current first item in the user LANGUAGE list,
         # but with country code added if not already present
-        locale = language2locale(self.userEnvLanguage)
-        code = re.split('[.@]', locale)[0]
+        loc = language2locale(self.userEnvLanguage)
+        code = re.split('[.@]', loc)[0]
 
         combo = self.combobox_input_method
         #cell = combo.get_child().get_cell_renderers()[0]
@@ -452,7 +460,7 @@ class GtkLanguageSelector(LanguageSelectorBase):
         currentIM = self.imSwitch.getInputMethodForLocale(code)
         if currentIM in (None, 'default'):
             currentIM = 'none'
-        #print "Current IM: "+currentIM
+        #print("Current IM: "+currentIM)
 
         # find out about the other options
         for (i, IM) in enumerate(self.imSwitch.getAvailableInputMethods()):
@@ -485,7 +493,7 @@ class GtkLanguageSelector(LanguageSelectorBase):
 
 #    @honorBlockedSignals
 #    def on_checkbutton_enable_input_methods_toggled(self, widget):
-#        #print "on_checkbutton_enable_input_methods_toggled()"
+#        #print("on_checkbutton_enable_input_methods_toggled()")
 #        active = self.checkbutton_enable_input_methods.get_active()
 #        self.combo_userlang_dirty = True
 #        self.setSensitive(False)
@@ -494,13 +502,13 @@ class GtkLanguageSelector(LanguageSelectorBase):
 
 #    @honorBlockedSignals
 #    def on_checkbutton_sync_languages_toggled(self, widget):
-#        #print "on_checkbutton_sync_languages_toggled()"
+#        #print("on_checkbutton_sync_languages_toggled()")
 #        if self.checkbutton_sync_languages.get_active() == True:
 #            self.combobox_user_language.set_active(self.combobox_system_language.get_active())
 #            self.updateSystemDefaultCombo()
         
     def build_commit_lists(self):
-        print self._cache.get_changes()
+        print(self._cache.get_changes())
 
         try:
             for (lang, langInfo) in self._langlist:
@@ -514,9 +522,9 @@ class GtkLanguageSelector(LanguageSelectorBase):
                   "this issue at first."))
             sys.exit(1)
         (to_inst, to_rm) = self._cache.getChangesList()
-        #print "inst: %s" % to_inst
-        #print "rm: %s" % to_rm
-        print self._cache.get_changes()
+        #print("inst: %s" % to_inst)
+        #print("rm: %s" % to_rm)
+        print(self._cache.get_changes())
         return (to_inst, to_rm)
 
     def error(self, summary, msg):
@@ -526,7 +534,7 @@ class GtkLanguageSelector(LanguageSelectorBase):
                               buttons=Gtk.ButtonsType.CLOSE)
         d.set_markup("<big><b>%s</b></big>\n\n%s" % (summary, msg))
         d.set_title=("")
-        res = d.run()
+        d.run()
         d.destroy()
 
     def _show_error_dialog(self, error):
@@ -546,10 +554,6 @@ class GtkLanguageSelector(LanguageSelectorBase):
         except SystemError:
             res = False
 
-        # check if we don't have unexpected changes
-        if not self._cache.verify_no_unexpected_changes():
-            return False
-
         # undo the selections
         self._cache.clear()
         if self._cache._depcache.broken_count != 0:
@@ -586,8 +590,8 @@ class GtkLanguageSelector(LanguageSelectorBase):
                   "\"System Settings... -> Software Sources\")."))
             self.setSensitive(True)
             return 0
-        #print "inst_list: %s " % inst_list
-        #print "rm_list: %s " % rm_list
+        #print("inst_list: %s " % inst_list)
+        #print("rm_list: %s " % rm_list)
         self.commit(inst_list, rm_list)
 
         self.setSensitive(True)
@@ -597,7 +601,7 @@ class GtkLanguageSelector(LanguageSelectorBase):
     def _run_transaction(self, transaction):
         dia = AptProgressDialog(transaction, parent=self.window_main)
         dia.connect("finished", self._on_finished)
-        dia.run()
+        dia.run(error_handler=self._on_error)
         
     def _wait_for_aptdaemon_finish(self):
         while not self._transaction_finished:
@@ -609,6 +613,18 @@ class GtkLanguageSelector(LanguageSelectorBase):
         dialog.hide()
         self._transaction_finished = True
 
+    def _on_error(self, error):
+        if hasattr(error, 'get_dbus_name') and error.get_dbus_name() == \
+                    'org.freedesktop.PolicyKit.Error.NotAuthorized':
+                self.error(
+                        _("Could not install the full language support"),
+                        _('Failed to authorize to install packages.'))
+        else:
+            self.error(
+                    _("Could not install the full language support"),
+                    str(error))
+        self._transaction_finished = True
+
     def update_aptdaemon(self):
         self._transaction_finished = False
         self._update_aptdaemon()
@@ -619,7 +635,7 @@ class GtkLanguageSelector(LanguageSelectorBase):
         try:
             trans = yield self.ac.update_cache(defer=True)
             self._run_transaction(trans)
-        except Exception, e:
+        except Exception as e:
             self._show_error_dialog(e)
 
     def commit_aptdaemon(self, inst, rm):
@@ -636,7 +652,7 @@ class GtkLanguageSelector(LanguageSelectorBase):
                 install=inst, reinstall=[], remove=rm, purge=[], upgrade=[],
                 downgrade=[], defer=True)
             self._run_transaction(trans)
-        except Exception, e:
+        except Exception as e:
             self._show_error_dialog(e)
 
     # we default with update/commit to aptdaemon
@@ -650,10 +666,10 @@ class GtkLanguageSelector(LanguageSelectorBase):
         """ called at the start to inform about possible missing
             langpacks (e.g. gnome/kde langpack transition)
         """
-        #print "verifyInstalledLangPacks"
+        #print("verifyInstalledLangPacks")
         missing = self.getMissingLangPacks()
 
-        #print "Missing: %s " % missing
+        #print("Missing: %s " % missing)
         if len(missing) > 0:
             # FIXME: add "details"
             d = Gtk.MessageDialog(parent=self.window_main,
@@ -693,7 +709,7 @@ class GtkLanguageSelector(LanguageSelectorBase):
                 self.setSensitive(True)
 
     def updateLanguageView(self):
-        #print "updateLanguageView()"
+        #print("updateLanguageView()")
         self._langlist.clear()
 
         progress = GtkProgress(self.dialog_progress, self.progressbar_cache,
@@ -711,14 +727,13 @@ class GtkLanguageSelector(LanguageSelectorBase):
             sys.exit(1)
 
         languageList = self._cache.getLanguageInformation()
-        #print "ll size: ", len(languageList)
-        #print "ll type: ", type(languageList)
+        #print("ll size: ", len(languageList))
+        #print("ll type: ", type(languageList))
         for lang in languageList:
-            #print "langInfo: %s (%s)" % (lang.language, lang.languageCode)
-            inconsistent = lang.inconsistent
+            #print("langInfo: %s (%s)" % (lang.language, lang.languageCode))
+            #inconsistent = lang.inconsistent
             #if inconsistent:
-            #    print "inconsistent", lang.language
-            installed = lang.fullInstalled
+            #    print("inconsistent", lang.language)
 
             # hack for Vietnamese users; see https://launchpad.net/bugs/783090
             # Even if calling self._localeinfo.translate() with native=True triggers
@@ -734,32 +749,27 @@ class GtkLanguageSelector(LanguageSelectorBase):
             self._langlist.append([lang_name, lang])
         self._langlist.set_sort_column_id(LIST_LANG, Gtk.SortType.ASCENDING)
 
-    def writeSystemDefaultLang(self):
+    def writeSystemFormats(self):
         combo = self.combobox_locale_chooser
         model = combo.get_model()
         if combo.get_active() < 0:
             return False
         (lang, code) = model[combo.get_active()]
-        (old_code, language_string) = self._localeinfo.getSystemDefaultLanguage()
+        old_code = self._localeinfo.getSystemDefaultLanguage()[0]
         # no changes, nothing to do
         macr = macros.LangpackMacros(self._datadir, old_code)
         if macr["LOCALE"] == code:
             return False
-        self.writeSysLangSetting(sysLang=code)
-        if self._localeinfo.isCompleteSystemLanguage():
-            return True
-        # set the system language completely in order to prevent surprises
-        # (the installer does not set system LC_* variables)
-        self.writeSysLanguageSetting(sysLanguage=language_string)
+        self.writeSysFormatsSetting(sysFormats=code)
         return True
 
-    def writeUserDefaultLang(self):
+    def writeUserFormats(self):
         combo = self.combobox_locale_chooser
         model = combo.get_model()
         if combo.get_active() < 0:
             return
         (lang, code) = model[combo.get_active()]
-        (temp, languageString) = self._localeinfo.getUserDefaultLanguage()
+        temp = self._localeinfo.getUserDefaultLanguage()[0]
         if temp == None:
             old_code = self._localeinfo.getSystemDefaultLanguage()[0]
         else:
@@ -768,21 +778,20 @@ class GtkLanguageSelector(LanguageSelectorBase):
         macr = macros.LangpackMacros(self._datadir, old_code)
         if macr["LOCALE"] == code:
             return False
-        self.writeUserLangSetting(userLang=code)
-        if self._localeinfo.isCompleteUserLanguage():
-            return True
-        # set the user language completely in order to prevent surprises
-        # (the installer does not set the user language for the user that
-        # is created at installation)
-        self.writeUserLanguageSetting(userLanguage=languageString)
+        self.writeUserFormatsSetting(userFormats=code)
         return True
 
     def writeSystemLanguage(self, languageString):
-        old_string = self._localeinfo.getSystemDefaultLanguage()[1]
+        (formats_locale, old_string) = self._localeinfo.getSystemDefaultLanguage()
         # no changes, nothing to do
         if old_string == languageString:
             return False
         self.writeSysLanguageSetting(sysLanguage=languageString)
+        if self._localeinfo.isSetSystemFormats():
+            return True
+        # set the system formats (certain LC_* variables) explicitly
+        # in order to prevent surprises when LANG is changed
+        self.writeSysFormatsSetting(sysFormats=formats_locale)
         return True
 
     def writeUserLanguage(self, languageString):
@@ -799,7 +808,7 @@ class GtkLanguageSelector(LanguageSelectorBase):
 
     @blockSignals
     def updateLocaleChooserCombo(self):
-        #print "updateLocaleChooserCombo()"
+        #print("updateLocaleChooserCombo()")
         combo = self.combobox_locale_chooser
         #XXX get_cell_renderers does not exist in GTK3
         #cell = combo.get_child().get_cell_renderers()[0]
@@ -807,6 +816,10 @@ class GtkLanguageSelector(LanguageSelectorBase):
         #cell.set_property("wrap-width",300)
         #cell.set_property("wrap-mode",Pango.WRAP_WORD)
         model = combo.get_model()
+
+        if not model:
+            return
+
         model.clear()
 
         # find the default
@@ -823,7 +836,9 @@ class GtkLanguageSelector(LanguageSelectorBase):
 
         """ languages for message translation """
         self._language_options.clear()
-        options = subprocess.check_output(['/usr/share/language-tools/language-options'])
+        options = subprocess.check_output(
+            ['/usr/share/language-tools/language-options'],
+            universal_newlines=True)
         mylist = []
         for (i, option) in enumerate( options.split("\n") ):
             mylist.append([self._localeinfo.translate(option, native=True), option])
@@ -842,13 +857,13 @@ class GtkLanguageSelector(LanguageSelectorBase):
             self._language_options.append(i)
 
         """ locales for misc. format preferences """
-        for (i, locale) in enumerate( self._localeinfo.generated_locales() ):
+        for (i, loc) in enumerate( self._localeinfo.generated_locales() ):
             iter = model.append()
             model.set_value(iter, LANGTREEVIEW_LANGUAGE,
-                    self._localeinfo.translate(locale, native=True))
-            model.set_value(iter, LANGTREEVIEW_CODE, locale)
+                    self._localeinfo.translate(loc, native=True))
+            model.set_value(iter, LANGTREEVIEW_CODE, loc)
             if (defaultLangName and
-                   self._localeinfo.translate(locale, native=True) == defaultLangName):
+                   self._localeinfo.translate(loc, native=True) == defaultLangName):
                 combo.set_active(i)
         self.updateExampleBox()
 
@@ -883,7 +898,7 @@ class GtkLanguageSelector(LanguageSelectorBase):
     #        duplicate too much code
 #    @blockSignals
 #    def updateUserDefaultCombo(self):
-#        #print "updateUserDefault()"
+#        #print("updateUserDefault()")
 #        combo = self.combobox_user_language
 #        cell = combo.get_child().get_cell_renderers()[0]
 #        # FIXME: use something else than a hardcoded value here
@@ -901,13 +916,13 @@ class GtkLanguageSelector(LanguageSelectorBase):
 #            defaultLangName = self._localeinfo.translate(defaultLangCode)
 
 #        # find out about the other options        
-#        for (i, locale) in enumerate(self._localeinfo.generated_locales()):
+#        for (i, loc) in enumerate(self._localeinfo.generated_locales()):
 #            iter = model.append()
 #            model.set(iter,
-#                      COMBO_LANGUAGE,self._localeinfo.translate(locale),
-#                      COMBO_CODE, locale)
+#                      COMBO_LANGUAGE,self._localeinfo.translate(loc),
+#                      COMBO_CODE, loc)
 #            if (defaultLangName and 
-#                   self._localeinfo.translate(locale) == defaultLangName):
+#                   self._localeinfo.translate(loc) == defaultLangName):
 #                combo.set_active(i)
 #            
 #        # reset the state of the apply button
@@ -919,14 +934,19 @@ class GtkLanguageSelector(LanguageSelectorBase):
         model = combo.get_model()
         if combo.get_active() < 0:
             return
+        self.label_example_currency.set_text('')
+        self.label_example_number.set_text('')
+        self.label_example_date.set_text('')
         (lang, code) = model[combo.get_active()]
         macr = macros.LangpackMacros(self._datadir, code)
-        mylocale = macr["SYSLOCALE"].encode('UTF-8')
+        mylocale = macr["SYSLOCALE"]
         try:
             locale.setlocale(locale.LC_ALL, mylocale)
-        except locale.Error as detail:
+        except locale.Error:
             self.label_example_date.set_text('[ '
-            + _("Failed to apply the '%s' format choice:") % mylocale + "\n%s ]" % detail)
+            + _("Failed to apply the '%s' format\n"
+                "choice. The examples may show up if you\n"
+                "close and re-open Language Support.") % mylocale + ' ]')
             return
         self.label_example_currency.set_text(locale.currency(20457.99))
         self.label_example_number.set_text(locale.format("%.2f", 1234567.89, grouping=True))
@@ -971,7 +991,7 @@ class GtkLanguageSelector(LanguageSelectorBase):
         #self.debug_pkg_status()
 
     def on_button_cancel_clicked(self, widget):
-        #print "button_cancel"
+        #print("button_cancel")
         self.window_installer.hide()
 
     def on_button_apply_clicked(self, widget):
@@ -996,9 +1016,10 @@ class GtkLanguageSelector(LanguageSelectorBase):
     @honorBlockedSignals
     def on_window_main_key_press_event(self, widget, event):
         keyname = Gdk.keyval_name(event.keyval)
-        if (event.get_state() & Gdk.ModifierType.CONTROL_MASK):
-            if (keyname == "w"):
-                Gtk.main_quit()
+        if event.get_state() & Gdk.ModifierType.CONTROL_MASK and keyname == "w":
+            Gtk.main_quit()
+        if event.get_state() == 0 and keyname == "Escape":
+            Gtk.main_quit()
         return None
 
     ####################################################
@@ -1018,7 +1039,7 @@ class GtkLanguageSelector(LanguageSelectorBase):
 
     @honorBlockedSignals
     def on_treeview_locales_drag_end(self, widget, drag_content):
-        #print ("on_treeview_locales_drag_end")
+        #print("on_treeview_locales_drag_end")
         model = widget.get_model()
         myiter = model.get_iter_first()
         envLanguage = ""
@@ -1030,7 +1051,7 @@ class GtkLanguageSelector(LanguageSelectorBase):
             if str == "en":
                 break
             myiter = model.iter_next(myiter)
-        #print (envLanguage)
+        #print(envLanguage)
         self.writeUserLanguage(envLanguage)
         self.userEnvLanguage = envLanguage
         self.check_input_methods()
@@ -1055,15 +1076,15 @@ class GtkLanguageSelector(LanguageSelectorBase):
 
     @honorBlockedSignals
     def on_combobox_input_method_changed(self, widget):
-        locale = language2locale(self.userEnvLanguage)
-        code = re.split('[.@]', locale)[0]
+        loc = language2locale(self.userEnvLanguage)
+        code = re.split('[.@]', loc)[0]
 
         combo = self.combobox_input_method
         model = combo.get_model()
         if combo.get_active() < 0:
             return
         (IM_choice, IM_name) = model[combo.get_active()]
-        #print "IM: "+IM_choice+"\t"+code
+        #print("IM: "+IM_choice+"\t"+code)
         self.imSwitch.setInputMethodForLocale(IM_choice, code)
 
     
@@ -1074,13 +1095,13 @@ class GtkLanguageSelector(LanguageSelectorBase):
     @insensitive
     def on_combobox_locale_chooser_changed(self, widget):
         self.check_input_methods()
-        self.writeUserDefaultLang()
+        self.writeUserFormats()
         self.updateLocaleChooserCombo()
         self.updateExampleBox()
 
     @honorBlockedSignals
     @insensitive
     def on_button_apply_system_wide_locale_clicked(self, widget):
-        self.writeSystemDefaultLang()
+        self.writeSystemFormats()
         return None
 
